IEEE 754 half-precision (binary16) floating-point type.
This is a minimal implementation providing only the operations needed for JPEG XL decoding,
avoiding external dependencies like half which pulls in zerocopy.
Structs
- f16
- IEEE 754 binary16 half-precision floating-point type.